@@ -357,7 +357,8 @@ sub hex2char {
     return undef unless $value;
     return $value unless $value =~ /^0x/;
 
-    $value =~ s/^0x//;
+    $value =~ s/^0x//; # drop hex prefix
+    $value =~ s/00$//; # drop trailing null-character
     $value =~ s/(\w{2})/chr(hex($1))/eg;
 
     return $value;
