@@ -25,25 +25,16 @@ sub test_port {
     if (socket(my $socket, PF_INET, SOCK_STREAM, $proto)) {
         if (connect($socket, $paddr)) {
             close $socket;
-            return 1;
+            return 0;
         } 
     }
 
-    return 0;
+    return 1;
 }
 
 sub test_localhost {
 
-    return 0 unless inet_aton('localhost');
-
-    my $ipv6;
-    eval {
-        my ($err, @result) = Socket::getaddrinfo("localhost", "http");
-        $ipv6 = any { $_->{family} == Socket::PF_INET6 } @result;
-    };
-    return 0 if $ipv6;
-
-    return 1;
+    return inet_aton('localhost');
 }
 
 sub mockGetWmiObjects {
